import numpy as np
from . import functions

__author__ = "Makar Kuznetsov"

class Network:
	def __init__(self, neurons, primers, answers, problem, * , seed=1, iterations=1000000, activation=functions.sigmoid):
		self.primers = primers
		self.answers = answers
		self.problem = problem
		self.syn_w = 2 * np.random.random((neurons, 1)) - 1
		self.iterations = iterations
		self.activation=activation
		np.random.seed(seed)
	def start_learn(self):
		for _ in range(self.iterations):
			input_layer = self.primers
			outputs = self.activation(np.dot(input_layer, self.syn_w))
			err = self.answers - outputs
			adjuments = np.dot(input_layer.T, err * (outputs * (1 - outputs)))
			self.syn_w += adjuments
			return self.syn_w
	def solve_problem(self):
		answer = self.activation(np.dot(self.problem, self.syn_w))
		return answer



from setuptools import setup

pytron_info = """
Pythontron.

Copyright © Makar Kuznetsov 2021. All rights reserved

License – GNU GPL.

See more information on Github.
"""

setup(
    name='pythontron',
    version='1.1',
    description='Python library for creating perceptrons.',
    long_description=pytron_info,
    url='http://github.com/HonestHacker123/pythontron',
    install_requires=['numpy'],
    packages=['pythontron'],
    author="Makar Kuznetsov",
    author_email='makar10kuznetsov@mail.ru',
    zip_safe=False
)
